@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+import ast
 from collections import ChainMap
 from contextlib import contextmanager, redirect_stdout
 from copy import copy, deepcopy
@@ -2474,3 +2475,23 @@ def in_standard_library(package_name):
         STANDARD_LIBRARY = json.loads(r.read())
     return package_name in STANDARD_LIBRARY
 
+
+def get_module_docstring(path, default=''):
+    """Got the module level docstring from a python file.
+
+    Parameters
+    ----------
+    path: str or Path
+        File to extract docstring from. You can also pass in __file__ to get
+        the current file.
+    default: str
+        Backup value when module has no docstring.
+
+    Returns
+    -------
+    str
+    """
+    with open(path, 'r') as f:
+        tree = ast.parse(f.read())
+    return ast.get_docstring(tree) or default
+
